@@ -16,7 +16,7 @@ module Slack
           attachments = wrap_array(attachments).map do |attachment|
             ["text", :text].each do |key|
               if attachment.key?(key)
-                attachment[key] = Util::LinkFormatter.format(attachment[key], options)
+                attachment[key] = Util::LinkFormatter.format(attachment[key], **options)
               end
             end
 
